﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;

using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;

namespace Grid_NoRows_Test
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            //When a row is deleted, the Currency Manager references the prior row 
            //   SyncWithCurrencyManager default true
            //   SyncWithCurrencyManagerAfterRowDeletion default false; true only applies if also SyncWithCurrencyManager = true
            Grid.SyncWithCurrencyManager = false;
            Grid.SyncWithCurrencyManagerAfterRowDeletion = false;

            Grid.DisplayLayout.NoDataSourceMessageEnabled = DefaultableBoolean.True;
            Grid.DisplayLayout.NoDataSourceMessageText = "NoDataSource Text.";
            Grid.DisplayLayout.NoDataSourceMessageAppearance.ForeColor = Color.Orange;
            Grid.DisplayLayout.Override.NoRowsInDataSourceMessageEnabled = DefaultableBoolean.True;
            Grid.DisplayLayout.Override.NoRowsInDataSourceMessageText = "NoRowsInSource Text";
            Grid.DisplayLayout.Override.NoRowsInDataSourceMessageAppearance.ForeColor = Color.Red;
            Grid.DisplayLayout.Override.NoVisibleRowsMessageEnabled = DefaultableBoolean.True;
            Grid.DisplayLayout.Override.NoVisibleRowsMessageText = "NoVisibleRows Text";
            Grid.DisplayLayout.Override.NoVisibleRowsMessageAppearance.ForeColor = Color.Purple;

            Grid.DisplayLayout.Override.AllowRowFiltering = DefaultableBoolean.True;
            Grid.DisplayLayout.Override.FilterUIType = FilterUIType.FilterRow;

            butAddRows.Enabled = true;
            butRemoveRows.Enabled = false;

            CreateTables();
            CreateBindingSource();
            Grid.DataSource = bdgSource;
        }

        DataTable table;
        DataTable tableWithRowsSource;
        private void CreateTables()
        {
            table = new DataTable();
            table.Columns.Add("TestInt1", typeof(int));
            table.Columns.Add("TestStr1", typeof(string));
            table.Columns.Add("TestStr2", typeof(string));
            table.Columns.Add("TestDt1", typeof(DateTime));

            tableWithRowsSource = new DataTable();
            tableWithRowsSource.Columns.Add("TestInt1", typeof(int));
            tableWithRowsSource.Columns.Add("TestStr1", typeof(string));
            tableWithRowsSource.Columns.Add("TestStr2", typeof(string));
            tableWithRowsSource.Columns.Add("TestDt1", typeof(DateTime));

            tableWithRowsSource.Rows.Add(25, "Indocin", "David", DateTime.Now);
            tableWithRowsSource.Rows.Add(50, "Enebrel", "Sam", DateTime.Now);
            tableWithRowsSource.Rows.Add(10, "Hydralazine", "Christoff", DateTime.Now);
            tableWithRowsSource.Rows.Add(21, "Combivent", "Janet", DateTime.Now);
            tableWithRowsSource.Rows.Add(100, "Dilantin", "Melanie", DateTime.Now);
        }

        BindingSource bdgSource;
        private void CreateBindingSource()
        {
            bdgSource = new BindingSource(tableWithRowsSource, null);
            bdgSource.Filter = "TestStr1 = 'asdf'";
            bdgSource.ListChanged += new ListChangedEventHandler(bdgSource_ListChanged);
        }

        private void bdgSource_ListChanged(object sender, ListChangedEventArgs e)
        {
            Debug.Print("bdgSource_ListChanged event, Type = " + e.ListChangedType);
            if (uceApplyWorkaround.Checked)
            {
                bool dsHasRows;
                if (uceUseDataTable.Checked)  // using table
                    dsHasRows = table.Rows.Count > 0;
                else // using bdgSource with tableWithRowsSource
                    dsHasRows = bdgSource.Count > 0;

                EmptyMessageRowUIElement uie = (EmptyMessageRowUIElement)Grid.DisplayLayout.UIElement.GetDescendant(typeof(EmptyMessageRowUIElement));
                if (uie != null)
                    uie.EmptyMessageRow.EmptyMessageType = dsHasRows ? EmptyMessageUIElement.EmptyMessageType.NoVisibleRows : EmptyMessageUIElement.EmptyMessageType.NoRows;
            }
        }

        private void butAddRows_Click(object sender, EventArgs e)
        {
            if (uceUseDataTable.Checked)
            {
                table.Rows.Add(25, "Indocin", "David", DateTime.Now);
                table.Rows.Add(50, "Enebrel", "Sam", DateTime.Now);
                table.Rows.Add(10, "Hydralazine", "Christoff", DateTime.Now);
                table.Rows.Add(21, "Combivent", "Janet", DateTime.Now);
                table.Rows.Add(100, "Dilantin", "Melanie", DateTime.Now);
            }
            else
                bdgSource.RemoveFilter();

            butAddRows.Enabled = false;
            butRemoveRows.Enabled = true;
        }

        private void butRemoveRows_Click(object sender, EventArgs e)
        {
            if (uceUseDataTable.Checked)
                table.Rows.Clear();
            else
                bdgSource.Filter = "TestStr1 = 'asdf'";

            butAddRows.Enabled = true;
            butRemoveRows.Enabled = false;
        }

        private void uceUseDataTable_CheckedChanged(object sender, EventArgs e)
        {
            if (uceUseDataTable.Checked)
                Grid.DataSource = table;
            else
                Grid.DataSource = bdgSource;
        }

        private void uceSyncCurrMgr_CheckedChanged(object sender, EventArgs e)
        {
            Grid.SyncWithCurrencyManager = uceSyncCurrMgr.Checked;  //default is true
        }

        private void uceSyncAfterRowDeletion_CheckedChanged(object sender, EventArgs e)
        {
            Grid.SyncWithCurrencyManagerAfterRowDeletion = uceSyncAfterRowDeletion.Checked;  // default is false
        }

    }
}
